@@ -18,6 +18,7 @@ from .contrib import (
     CachedFeatureFlagStore,
     ConsulFeatureFlagStore,
     MemoryFeatureFlagStore,
+    PostgreSQLFeatureFlagStore,
     RedisFeatureFlagStore,
     ReplicatedFeatureFlagStore,
     S3FeatureFlagStore,
@@ -33,6 +34,7 @@ __all__ = [
     "FeatureFlagClient",
     "FlagDoesNotExistError",
     "MemoryFeatureFlagStore",
+    "PostgreSQLFeatureFlagStore",
     "RedisFeatureFlagStore",
     "ReplicatedFeatureFlagStore",
     "S3FeatureFlagStore",
